@@ -16,21 +16,18 @@ using namespace BamTools;
 using namespace BamTools::Internal;
 
 #include <iostream>
-using namespace std;
 
-IBamIODevice* BamDeviceFactory::CreateDevice(const string& source) {
+IBamIODevice* BamDeviceFactory::CreateDevice(const std::string& source)
+{
 
     // check for requested pipe
-    if ( source == "-" || source == "stdin" || source == "stdout" )
-        return new BamPipe;
+    if (source == "-" || source == "stdin" || source == "stdout") return new BamPipe;
 
     // check for HTTP prefix
-    if ( source.find("http://") == 0 )
-        return new BamHttp(source);
+    if (source.find("http://") == 0) return new BamHttp(source);
 
     // check for FTP prefix
-    if ( source.find("ftp://") == 0 )
-        return new BamFtp(source);
+    if (source.find("ftp://") == 0) return new BamFtp(source);
 
     // otherwise assume a "normal" file
     return new BamFile(source);
